<?php
/**
 * contentinum - accessibility websites
 *
 * LICENSE
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * @category Mcwork
 * @package Model
 * @author Michael Jochum, michael.jochum@jochum-mediaservices.de
 * @copyright Copyright (c) 2009-2013 jochum-mediaservices, Katja Jochum (http://www.jochum-mediaservices.de)
 * @license http://www.opensource.org/licenses/bsd-license
 * @since contentinum version 5.0
 * @link      https://github.com/Mikel1961/contentinum-components
 * @version   1.0.0
 */
namespace Mcwork\Model\Recycle;

use Mcwork\Model\Save\AbstractContribution;
use Mcwork\Model\Save\ContributionGroup;

class Contribution extends AbstractContribution
{

    /**
     * Prepare datas before save
     *
     * @see \ContentinumComponents\Mapper\Process::save()
     */
    public function save($datas, $entity = null, $stage = '', $id = null)
    {
        $entity = $this->handleEntity($entity);
        
        if (isset($datas['id'])) {
            $lastInsertId = $datas['id'];
            unset($datas['id']);
            $datas['deleted'] = '0';
            $this->inUseMedia($entity->webMediasId->id, $entity->id, self::INUSE_GROUP, 'delete');
            parent::save($datas, $entity, $stage, $id);
            $this->assignGroup($datas, $lastInsertId);
            $this->inUseMedia($datas['webMediasId'], $entity->id);
        }
        return true;
    }

    /**
     *
     * @param unknown $datas            
     * @param unknown $lastInsertId            
     */
    protected function assignGroup($datas, $lastInsertId)
    {
        $insert['webContent'] = $this->find($lastInsertId, true);
        $this->unsetTargetEntities();
        $this->setTargetEntities(array(
            'webContent' => $this->getEntityName()
        ));
        $this->unsetEntity();
        $this->setEntity($this->getSl()
            ->get('Entity\ContentGroups'));
        if (false == $datas['webContentgroup']) {
            $insert['itemRang'] = 1;
            $insert['webContentgroup'] = $this->sequence() + 1;
            $assignInPage = true;
        } else {
            $insert['webContentgroup'] = $datas['webContentgroup'];
            $insert['itemRang'] = $this->sequence('webContentgroup', $insert['webContentgroup'], 'itemRang') + 1;
            $assignInPage = false;
        }
        
        parent::save($insert, $this->getSl()->get('Entity\ContentGroups'));
        if (true === $assignInPage) {
            $lastInsertId = $this->getLastInsertId();
            $datas['webContentgroup'] = $this->getLastInsertId();
            $inPage = new ContributionGroup($this->getStorage());
            $inPage->setSl($this->getSl());
            $inPage->setEntity($this->getSl()
                ->get('Entity\PageContent'));
            $inPage->insertContribution($datas);
        }
    }
}